# xprint

## Development Environment

- Windows 10
- Python 3.7.0

## Installation

```
$ pip3 install xprint
```

## Usage

Import:

```
import xprint as xp

# xp.init()
```

Base:

- xp.wr()
- xp.fi()

Usage:

- xp.success()
- xp.error()
- xp.value()
- xp.step()
- xp.job()
- xp.about_t()
- xp.about_to()
- xp.getting()
- ...
